==> koffice2_1.9.98.5.orig.tar.gz: koffice-1.9.98.5/krita/image/commands/kis_image_layer_remove_command.h <==
/*
 *  Copyright (c) 2002 Patrick Julien <freak@codepimps.org>
 *  Copyright (c) 2007 Sven Langkamp <sven.langkamp@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef KIS_IMAGE_LAYER_REMOVE_COMMAND_H_
#define KIS_IMAGE_LAYER_REMOVE_COMMAND_H_

#include <krita_export.h>

#include <QUndoCommand>
#include <QSize>
#include <QBitArray>
#include "kis_types.h"
#include "kis_image_command.h"

class KoCompositeOp;
class KoColorSpace;
class KoColorProfile;

/// The command for removing a layer
class KisImageLayerRemoveCommand : public KisImageCommand
{


public:
    /**
     * Constructor
     * @param image The image the command will be working on.
     * @param layer the layer to remove
     * @param wasParent the parent of the layer
     * @param wasAbove the layer above the layer
     */
    KisImageLayerRemoveCommand(KisImageSP image, KisNodeSP layer, KisNodeSP wasParent, KisNodeSP wasAbove);

    virtual void redo();
    virtual void undo();

private:
    KisNodeSP m_layer;
    KisNodeSP m_prevParent;
    KisNodeSP m_prevAbove;
};
#endif

==> koffice2_2.0.0.orig.tar.gz: koffice-2.0.0/krita/image/commands/kis_image_layer_remove_command.h <==
/*
 *  Copyright (c) 2002 Patrick Julien <freak@codepimps.org>
 *  Copyright (c) 2007 Sven Langkamp <sven.langkamp@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef KIS_IMAGE_LAYER_REMOVE_COMMAND_H_
#define KIS_IMAGE_LAYER_REMOVE_COMMAND_H_

#include <krita_export.h>

#include <QUndoCommand>
#include <QSize>
#include <QBitArray>
#include "kis_types.h"
#include "kis_image_command.h"


class KoCompositeOp;
class KoColorSpace;
class KoColorProfile;

/// The command for removing a layer
class KRITAIMAGE_EXPORT KisImageLayerRemoveCommand : public KisImageCommand
{


public:
    /**
     * Constructor
     * @param image The image the command will be working on.
     * @param layer the layer to remove
     * @param wasParent the parent of the layer
     * @param wasAbove the layer above the layer
     */
    KisImageLayerRemoveCommand(KisImageSP image, KisNodeSP layer);

    virtual void redo();
    virtual void undo();

private:
    KisNodeSP m_layer;
    KisNodeSP m_prevParent;
    KisNodeSP m_prevAbove;
};
#endif
